Documentation
¶
Overview ¶
SPDX-License-Identifier: Apache-2.0 Copyright Authors of Cilium
Index ¶
- Constants
- Variables
- type BPFOps
- func (ops *BPFOps) Delete(_ context.Context, _ statedb.ReadTxn, _ statedb.Revision, ...) error
- func (ops *BPFOps) GetLastUpdatedAt() time.Time
- func (ops *BPFOps) Prune(_ context.Context, _ statedb.ReadTxn, ...) error
- func (ops *BPFOps) ResetAndRestore() (err error)
- func (ops *BPFOps) StateIsEmpty() bool
- func (ops *BPFOps) StateSummary() string
- func (ops *BPFOps) Update(_ context.Context, txn statedb.ReadTxn, _ statedb.Revision, ...) error
Constants ¶
Variables ¶
var Cell = cell.Module( "loadbalancer-reconciler", "Load-balancing BPF map reconciliation", cell.Provide( newBPFOps, scriptCommands, ), cell.ProvidePrivate( newBPFReconciler, ), cell.Invoke( func(promise.Promise[reconciler.Reconciler[*loadbalancer.Frontend]]) {}, ), SocketTerminationCell, )
Load-balancing tables to BPF map reconciliation.
Reconciles changes in Table[*Frontend] to the BPF maps.
var SocketTerminationCell = cell.Module( "socket-termination", "Terminates sockets connected to deleted backends", cell.ProvidePrivate( func() netnsOps { return netnsOps{ current: netns.Current, do: (*netns.NetNS).Do, all: netns.All, } }, func() socketDestroyerFactory { return makeSocketDestroyer }, ), cell.Invoke(registerSocketTermination), )
SocketTerminationCell runs a background job that monitors the backends table for unhealthy and deleted backends and terminates UDP & TCP sockets connected to these backends to signal to the application that the destination has become unreachable.
Functions ¶
This section is empty.
Types ¶
type BPFOps ¶
func (*BPFOps) Delete ¶
func (ops *BPFOps) Delete(_ context.Context, _ statedb.ReadTxn, _ statedb.Revision, fe *loadbalancer.Frontend) error
Delete implements reconciler.Operations.
func (*BPFOps) GetLastUpdatedAt ¶
func (*BPFOps) Prune ¶
func (ops *BPFOps) Prune(_ context.Context, _ statedb.ReadTxn, _ iter.Seq2[*loadbalancer.Frontend, statedb.Revision]) error
Prune implements reconciler.Operations.
func (*BPFOps) ResetAndRestore ¶
func (*BPFOps) StateIsEmpty ¶
func (*BPFOps) StateSummary ¶
StateSummary returns a multi-line summary of the internal state. Used in tests.
Click to show internal directories.
Click to hide internal directories.